@@ -1,11 +1,9 @@
-context("schedule")
-
 test_that("schedule", {
   schedule <- ypr_tabulate_schedule(ypr_population(
     Rmax = 100, Rk = 2, Wa = 0.01,
     n = ypr:::inst2inter(0.2), fa = 0.1
   ))
-  expect_null(chk::check_data(
+  expect_error(chk::check_data(
     schedule,
     values = list(
       Age = c(0L, 100L),
@@ -21,7 +19,7 @@ test_that("schedule", {
       FishedSurvivorship = c(0, 1)
     ),
     nrow = TRUE, exclusive = TRUE, order = TRUE
-  ))
+  ), NA)
 
   expect_true(all(diff(schedule$Age) == 1L))
 
